# fxrelay-ui

fxrelay-ui is a terminal-based interface for managing mailboxes on your [Firefox Relay](https://relay.firefox.com/) account.

TODO ![screenshot of fxrelay-ui showing several addresses](screenshot.png)

## Install

    pipx install fxrelay-ui

## License

fxrelay-ui is licensed under the [WTFPL](COPYING.WTFPL)
